==> pocl_0.10.orig.tar.gz: pocl-0.10/lib/CL/clFlush.c <==
/* OpenCL runtime library: clFlush()

   Copyright (c) 2012 Pekka Jääskeläinen
   
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:
   
   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.
   
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/

#include "pocl_cl.h"
#include "utlist.h"

CL_API_ENTRY cl_int CL_API_CALL
POname(clFlush)(cl_command_queue command_queue) CL_API_SUFFIX__VERSION_1_0
{
  /* "clFlush only guarantees that all queued commands to command_queue
     will eventually be submitted to the appropriate device. There is no guarantee 
     that they will be complete after clFlush returns." */
  /* This could be implemented as an asyc clFinish(), executing it in another
     thread? */
  return POname(clFinish) (command_queue);
}
POsym(clFlush)

==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/CL/clFlush.c <==
/* OpenCL runtime library: clFlush()

   Copyright (c) 2012 Pekka Jääskeläinen
   
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:
   
   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.
   
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/

#include "pocl_cl.h"
#include "utlist.h"
#include "assert.h"

CL_API_ENTRY cl_int CL_API_CALL
POname(clFlush)(cl_command_queue command_queue) CL_API_SUFFIX__VERSION_1_0
{

  /* Some AMD tests assume that flushed commands will be asynchronously 
     executed. Call join here so that possible blocking device can execute 
     commands here. */

  if(command_queue->device->ops->flush)
    command_queue->device->ops->flush (command_queue->device, command_queue);
  
  return CL_SUCCESS;
}
POsym(clFlush)
